"""add tables.

Revision ID: 4762c850f79c
Revises: 19817d37d895
Create Date: 2024-04-03 13:33:58.396801

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "4762c850f79c"
down_revision: Union[str, None] = "19817d37d895"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Pushes changes into the database."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "arg",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_table(
        "arg_type",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_table(
        "array",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.Column("task_template_version_id", sa.Integer(), nullable=True),
        sa.Column("workflow_id", sa.Integer(), nullable=True),
        sa.Column("max_concurrently_running", sa.Integer(), nullable=False),
        sa.Column("created_date", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint(
            "task_template_version_id",
            "workflow_id",
            name="uc_task_template_version_id_workflow_id",
        ),
    )
    op.create_index(op.f("ix_array_name"), "array", ["name"], unique=False)
    op.create_index(
        op.f("ix_array_task_template_version_id"),
        "array",
        ["task_template_version_id"],
        unique=False,
    )
    op.create_index(
        op.f("ix_array_workflow_id"), "array", ["workflow_id"], unique=False
    )
    op.create_table(
        "cluster_type",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.Column("logfile_templates", sa.String(length=500), nullable=True),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_table(
        "dag",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("hash", sa.VARCHAR(length=150), nullable=False),
        sa.Column("created_date", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("hash"),
    )
    op.create_table(
        "edge",
        sa.Column("dag_id", sa.Integer(), nullable=False),
        sa.Column("node_id", sa.Integer(), nullable=False),
        sa.Column("upstream_node_ids", sa.JSON(), nullable=True),
        sa.Column("downstream_node_ids", sa.JSON(), nullable=True),
        sa.PrimaryKeyConstraint("dag_id", "node_id"),
    )
    op.create_table(
        "node",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("task_template_version_id", sa.Integer(), nullable=False),
        sa.Column("node_args_hash", sa.VARCHAR(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint(
            "task_template_version_id",
            "node_args_hash",
            name="uc_task_template_version_id_node_args_hash",
        ),
    )
    op.create_index(
        op.f("ix_node_task_template_version_id"),
        "node",
        ["task_template_version_id"],
        unique=False,
    )
    op.create_table(
        "node_arg",
        sa.Column("node_id", sa.Integer(), nullable=False),
        sa.Column("arg_id", sa.Integer(), nullable=False),
        sa.Column("val", sa.String(length=2048), nullable=False),
        sa.PrimaryKeyConstraint("node_id", "arg_id"),
    )
    op.create_table(
        "task_arg",
        sa.Column("task_id", sa.Integer(), nullable=False),
        sa.Column("arg_id", sa.Integer(), nullable=False),
        sa.Column("val", sa.String(length=2048), nullable=False),
        sa.PrimaryKeyConstraint("task_id", "arg_id"),
    )
    op.create_table(
        "task_attribute_type",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_table(
        "task_instance_status",
        sa.Column("id", sa.String(length=1), nullable=False),
        sa.Column("label", sa.String(length=150), nullable=False),
        sa.Column("description", sa.String(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "task_resources_type",
        sa.Column("id", sa.String(length=1), nullable=False),
        sa.Column("label", sa.String(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "task_status",
        sa.Column("id", sa.String(length=1), nullable=False),
        sa.Column("label", sa.String(length=150), nullable=False),
        sa.Column("description", sa.String(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "task_template_version",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("task_template_id", sa.Integer(), nullable=False),
        sa.Column("command_template", sa.Text(), nullable=False),
        sa.Column("arg_mapping_hash", sa.VARCHAR(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "fkidx_task_template_version_task_template_id",
        "task_template_version",
        ["task_template_id"],
        unique=False,
    )
    op.create_index(
        "ix_task_template_id",
        "task_template_version",
        ["task_template_id"],
        unique=False,
    )
    op.create_index(
        "uc_ttv_composite_pk",
        "task_template_version",
        ["task_template_id", "command_template", "arg_mapping_hash"],
        unique=True,
        mysql_length={"command_template": 617},
    )
    op.create_table(
        "tool",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_table(
        "workflow_attribute_type",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_table(
        "workflow_run_status",
        sa.Column("id", sa.String(length=1), nullable=False),
        sa.Column("label", sa.String(length=150), nullable=False),
        sa.Column("description", sa.String(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "workflow_status",
        sa.Column("id", sa.String(length=1), nullable=False),
        sa.Column("label", sa.String(length=150), nullable=False),
        sa.Column("description", sa.String(length=150), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "cluster",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.Column("cluster_type_id", sa.Integer(), nullable=False),
        sa.Column("connection_parameters", sa.String(length=2500), nullable=True),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name"),
    )
    op.create_index(
        "fkidx_cluster_cluster_type_id", "cluster", ["cluster_type_id"], unique=False
    )
    op.create_table(
        "template_arg_map",
        sa.Column("task_template_version_id", sa.Integer(), nullable=False),
        sa.Column("arg_id", sa.Integer(), nullable=False),
        sa.Column("arg_type_id", sa.Integer(), nullable=False),
        sa.PrimaryKeyConstraint("task_template_version_id", "arg_id", "arg_type_id"),
    )
    op.create_index(
        "fkidx_template_arg_map_arg_id", "template_arg_map", ["arg_id"], unique=False
    )
    op.create_index(
        "fkidx_template_arg_map_arg_type_id",
        "template_arg_map",
        ["arg_type_id"],
        unique=False,
    )
    op.create_index(
        "fkidx_template_arg_map_task_template_version_id",
        "template_arg_map",
        ["task_template_version_id"],
        unique=False,
    )
    op.create_table(
        "tool_version",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("tool_id", sa.Integer(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "fkidx_tool_version_tool_id", "tool_version", ["tool_id"], unique=False
    )
    op.create_table(
        "queue",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.Column("cluster_id", sa.Integer(), nullable=False),
        sa.Column("parameters", sa.String(length=2500), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("name", "cluster_id", name="uc_name_cluster_id"),
    )
    op.create_index("fkidx_queue_cluster_id", "queue", ["cluster_id"], unique=False)
    op.create_table(
        "task_template",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("tool_version_id", sa.Integer(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=255), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("tool_version_id", "name", name="uc_tool_version_id_name"),
    )
    op.create_index(
        "fkidx_task_template_tool_version_id",
        "task_template",
        ["tool_version_id"],
        unique=False,
    )
    op.create_table(
        "workflow",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("tool_version_id", sa.Integer(), nullable=True),
        sa.Column("dag_id", sa.Integer(), nullable=False),
        sa.Column("workflow_args_hash", sa.VARCHAR(length=150), nullable=False),
        sa.Column("task_hash", sa.VARCHAR(length=150), nullable=False),
        sa.Column("description", sa.Text(), nullable=True),
        sa.Column("name", sa.String(length=255), nullable=True),
        sa.Column("workflow_args", sa.Text(), nullable=True),
        sa.Column("max_concurrently_running", sa.Integer(), nullable=False),
        sa.Column("created_date", sa.DateTime(), nullable=True),
        sa.Column("status_date", sa.DateTime(), nullable=True),
        sa.Column("status", sa.String(length=1), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index("fkidx_workflow_dag_id", "workflow", ["dag_id"], unique=False)
    op.create_index("fkidx_workflow_status", "workflow", ["status"], unique=False)
    op.create_index(
        "fkidx_workflow_tool_version_id", "workflow", ["tool_version_id"], unique=False
    )
    op.create_index(
        op.f("ix_workflow_task_hash"), "workflow", ["task_hash"], unique=False
    )
    op.create_index(
        op.f("ix_workflow_workflow_args_hash"),
        "workflow",
        ["workflow_args_hash"],
        unique=False,
    )
    op.create_table(
        "task_resources",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("queue_id", sa.Integer(), nullable=True),
        sa.Column("task_resources_type_id", sa.String(length=1), nullable=False),
        sa.Column("requested_resources", sa.Text(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "fkidx_task_resources_queue_id", "task_resources", ["queue_id"], unique=False
    )
    op.create_index(
        "fkidx_task_resources_task_resources_type_id",
        "task_resources",
        ["task_resources_type_id"],
        unique=False,
    )
    op.create_table(
        "workflow_attribute",
        sa.Column("workflow_id", sa.Integer(), nullable=False),
        sa.Column("workflow_attribute_type_id", sa.Integer(), nullable=False),
        sa.Column("value", sa.String(length=255), nullable=True),
        sa.PrimaryKeyConstraint("workflow_id", "workflow_attribute_type_id"),
    )
    op.create_index(
        "fkidx_workflow_attribute_workflow_attribute_type_id",
        "workflow_attribute",
        ["workflow_attribute_type_id"],
        unique=False,
    )
    op.create_index(
        "fkidx_workflow_attribute_workflow_id",
        "workflow_attribute",
        ["workflow_id"],
        unique=False,
    )
    op.create_table(
        "workflow_run",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("workflow_id", sa.Integer(), nullable=False),
        sa.Column("user", sa.String(length=150), nullable=True),
        sa.Column("jobmon_version", sa.String(length=150), nullable=True),
        sa.Column("jobmon_server_version", sa.String(length=150), nullable=True),
        sa.Column("status", sa.String(length=1), nullable=False),
        sa.Column("created_date", sa.DateTime(), nullable=True),
        sa.Column("status_date", sa.DateTime(), nullable=True),
        sa.Column("heartbeat_date", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "fkidx_workflow_run_status", "workflow_run", ["status"], unique=False
    )
    op.create_index(
        "fkidx_workflow_run_workflow_id", "workflow_run", ["workflow_id"], unique=False
    )
    op.create_index(
        "ix_status_version",
        "workflow_run",
        ["status", "jobmon_version", "jobmon_server_version"],
        unique=False,
    )
    op.create_table(
        "task",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("workflow_id", sa.Integer(), nullable=True),
        sa.Column("node_id", sa.Integer(), nullable=True),
        sa.Column("task_args_hash", sa.VARCHAR(length=150), nullable=False),
        sa.Column("array_id", sa.Integer(), nullable=True),
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.Column("command", sa.Text(), nullable=False),
        sa.Column("task_resources_id", sa.Integer(), nullable=True),
        sa.Column("num_attempts", sa.Integer(), nullable=False),
        sa.Column("max_attempts", sa.Integer(), nullable=False),
        sa.Column("resource_scales", sa.String(length=1000), nullable=True),
        sa.Column("fallback_queues", sa.String(length=1000), nullable=True),
        sa.Column("status", sa.String(length=1), nullable=False),
        sa.Column("status_date", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index("fkidx_task_array_id", "task", ["array_id"], unique=False)
    op.create_index("fkidx_task_node_id", "task", ["node_id"], unique=False)
    op.create_index("fkidx_task_status", "task", ["status"], unique=False)
    op.create_index(
        "fkidx_task_task_resources_id", "task", ["task_resources_id"], unique=False
    )
    op.create_index("fkidx_task_workflow_id", "task", ["workflow_id"], unique=False)
    op.create_index(op.f("ix_task_name"), "task", ["name"], unique=False)
    op.create_index(op.f("ix_task_status_date"), "task", ["status_date"], unique=False)
    op.create_index(
        op.f("ix_task_task_args_hash"), "task", ["task_args_hash"], unique=False
    )
    op.create_index(
        "ix_workflow_id_status_date",
        "task",
        ["workflow_id", "status_date"],
        unique=False,
    )
    op.create_table(
        "task_attribute",
        sa.Column("task_id", sa.Integer(), nullable=False),
        sa.Column("task_attribute_type_id", sa.Integer(), nullable=False),
        sa.Column("value", sa.String(length=255), nullable=True),
        sa.PrimaryKeyConstraint("task_id", "task_attribute_type_id"),
    )
    op.create_index(
        "fkidx_task_attribute_task_attribute_type_id",
        "task_attribute",
        ["task_attribute_type_id"],
        unique=False,
    )
    op.create_index(
        "fkidx_task_attribute_task_id", "task_attribute", ["task_id"], unique=False
    )
    op.create_table(
        "task_instance",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("workflow_run_id", sa.Integer(), nullable=False),
        sa.Column("array_id", sa.Integer(), nullable=False),
        sa.Column("task_id", sa.Integer(), nullable=False),
        sa.Column("distributor_id", sa.String(length=20), nullable=True),
        sa.Column("task_resources_id", sa.Integer(), nullable=False),
        sa.Column("array_batch_num", sa.Integer(), nullable=False),
        sa.Column("array_step_id", sa.Integer(), nullable=False),
        sa.Column("nodename", sa.String(length=150), nullable=True),
        sa.Column("process_group_id", sa.Integer(), nullable=True),
        sa.Column("usage_str", sa.String(length=250), nullable=True),
        sa.Column("wallclock", sa.String(length=50), nullable=True),
        sa.Column("maxrss", sa.String(length=50), nullable=True),
        sa.Column("maxpss", sa.String(length=50), nullable=True),
        sa.Column("cpu", sa.String(length=50), nullable=True),
        sa.Column("io", sa.String(length=50), nullable=True),
        sa.Column("stdout", sa.String(length=2048), nullable=True),
        sa.Column("stderr", sa.String(length=2048), nullable=True),
        sa.Column("stdout_log", sa.Text(), nullable=True),
        sa.Column("stderr_log", sa.Text(), nullable=True),
        sa.Column("status", sa.String(length=1), nullable=False),
        sa.Column("submitted_date", sa.DateTime(), nullable=True),
        sa.Column("status_date", sa.DateTime(), nullable=True),
        sa.Column("report_by_date", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "fkidx_task_instance_array_id", "task_instance", ["array_id"], unique=False
    )
    op.create_index(
        "fkidx_task_instance_status", "task_instance", ["status"], unique=False
    )
    op.create_index(
        "fkidx_task_instance_task_id", "task_instance", ["task_id"], unique=False
    )
    op.create_index(
        "fkidx_task_instance_task_resources_id",
        "task_instance",
        ["task_resources_id"],
        unique=False,
    )
    op.create_index(
        "fkidx_task_instance_workflow_run_id",
        "task_instance",
        ["workflow_run_id"],
        unique=False,
    )
    op.create_index(
        "ix_array_batch_index",
        "task_instance",
        ["array_id", "array_batch_num", "array_step_id"],
        unique=False,
    )
    op.create_index(
        "ix_status_status_date",
        "task_instance",
        ["status", "status_date"],
        unique=False,
    )
    op.create_index(
        op.f("ix_task_instance_array_batch_num"),
        "task_instance",
        ["array_batch_num"],
        unique=False,
    )
    op.create_index(
        op.f("ix_task_instance_array_step_id"),
        "task_instance",
        ["array_step_id"],
        unique=False,
    )
    op.create_index(
        op.f("ix_task_instance_distributor_id"),
        "task_instance",
        ["distributor_id"],
        unique=False,
    )
    op.create_index(
        op.f("ix_task_instance_task_resources_id"),
        "task_instance",
        ["task_resources_id"],
        unique=False,
    )
    op.create_table(
        "task_instance_error_log",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("task_instance_id", sa.Integer(), nullable=False),
        sa.Column("error_time", sa.DateTime(), nullable=True),
        sa.Column("description", sa.Text(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "fkidx_task_instance_error_log_task_instance_id",
        "task_instance_error_log",
        ["task_instance_id"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    """Reverts changes performed by upgrade()."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "fkidx_task_instance_error_log_task_instance_id",
        table_name="task_instance_error_log",
    )
    op.drop_table("task_instance_error_log")
    op.drop_index(
        op.f("ix_task_instance_task_resources_id"), table_name="task_instance"
    )
    op.drop_index(op.f("ix_task_instance_distributor_id"), table_name="task_instance")
    op.drop_index(op.f("ix_task_instance_array_step_id"), table_name="task_instance")
    op.drop_index(op.f("ix_task_instance_array_batch_num"), table_name="task_instance")
    op.drop_index("ix_status_status_date", table_name="task_instance")
    op.drop_index("ix_array_batch_index", table_name="task_instance")
    op.drop_index("fkidx_task_instance_workflow_run_id", table_name="task_instance")
    op.drop_index("fkidx_task_instance_task_resources_id", table_name="task_instance")
    op.drop_index("fkidx_task_instance_task_id", table_name="task_instance")
    op.drop_index("fkidx_task_instance_status", table_name="task_instance")
    op.drop_index("fkidx_task_instance_array_id", table_name="task_instance")
    op.drop_table("task_instance")
    op.drop_index("fkidx_task_attribute_task_id", table_name="task_attribute")
    op.drop_index(
        "fkidx_task_attribute_task_attribute_type_id", table_name="task_attribute"
    )
    op.drop_table("task_attribute")
    op.drop_index("ix_workflow_id_status_date", table_name="task")
    op.drop_index(op.f("ix_task_task_args_hash"), table_name="task")
    op.drop_index(op.f("ix_task_status_date"), table_name="task")
    op.drop_index(op.f("ix_task_name"), table_name="task")
    op.drop_index("fkidx_task_workflow_id", table_name="task")
    op.drop_index("fkidx_task_task_resources_id", table_name="task")
    op.drop_index("fkidx_task_status", table_name="task")
    op.drop_index("fkidx_task_node_id", table_name="task")
    op.drop_index("fkidx_task_array_id", table_name="task")
    op.drop_table("task")
    op.drop_index("ix_status_version", table_name="workflow_run")
    op.drop_index("fkidx_workflow_run_workflow_id", table_name="workflow_run")
    op.drop_index("fkidx_workflow_run_status", table_name="workflow_run")
    op.drop_table("workflow_run")
    op.drop_index(
        "fkidx_workflow_attribute_workflow_id", table_name="workflow_attribute"
    )
    op.drop_index(
        "fkidx_workflow_attribute_workflow_attribute_type_id",
        table_name="workflow_attribute",
    )
    op.drop_table("workflow_attribute")
    op.drop_index(
        "fkidx_task_resources_task_resources_type_id", table_name="task_resources"
    )
    op.drop_index("fkidx_task_resources_queue_id", table_name="task_resources")
    op.drop_table("task_resources")
    op.drop_index(op.f("ix_workflow_workflow_args_hash"), table_name="workflow")
    op.drop_index(op.f("ix_workflow_task_hash"), table_name="workflow")
    op.drop_index("fkidx_workflow_tool_version_id", table_name="workflow")
    op.drop_index("fkidx_workflow_status", table_name="workflow")
    op.drop_index("fkidx_workflow_dag_id", table_name="workflow")
    op.drop_table("workflow")
    op.drop_index("fkidx_task_template_tool_version_id", table_name="task_template")
    op.drop_table("task_template")
    op.drop_index("fkidx_queue_cluster_id", table_name="queue")
    op.drop_table("queue")
    op.drop_index("fkidx_tool_version_tool_id", table_name="tool_version")
    op.drop_table("tool_version")
    op.drop_index(
        "fkidx_template_arg_map_task_template_version_id", table_name="template_arg_map"
    )
    op.drop_index("fkidx_template_arg_map_arg_type_id", table_name="template_arg_map")
    op.drop_index("fkidx_template_arg_map_arg_id", table_name="template_arg_map")
    op.drop_table("template_arg_map")
    op.drop_index("fkidx_cluster_cluster_type_id", table_name="cluster")
    op.drop_table("cluster")
    op.drop_table("workflow_status")
    op.drop_table("workflow_run_status")
    op.drop_table("workflow_attribute_type")
    op.drop_table("tool")
    op.drop_index(
        "uc_ttv_composite_pk",
        table_name="task_template_version",
        mysql_length={"command_template": 617},
    )
    op.drop_index("ix_task_template_id", table_name="task_template_version")
    op.drop_index(
        "fkidx_task_template_version_task_template_id",
        table_name="task_template_version",
    )
    op.drop_table("task_template_version")
    op.drop_table("task_status")
    op.drop_table("task_resources_type")
    op.drop_table("task_instance_status")
    op.drop_table("task_attribute_type")
    op.drop_table("task_arg")
    op.drop_table("node_arg")
    op.drop_index(op.f("ix_node_task_template_version_id"), table_name="node")
    op.drop_table("node")
    op.drop_table("edge")
    op.drop_table("dag")
    op.drop_table("cluster_type")
    op.drop_index(op.f("ix_array_workflow_id"), table_name="array")
    op.drop_index(op.f("ix_array_task_template_version_id"), table_name="array")
    op.drop_index(op.f("ix_array_name"), table_name="array")
    op.drop_table("array")
    op.drop_table("arg_type")
    op.drop_table("arg")
    # ### end Alembic commands ###
